@@ -20,17 +20,18 @@ a way to adapt params with datasets.
 import time
 import copy
 from pathlib import Path
-import threading
-import shutil
 import os
 import datetime
 import json
 import traceback
+import shutil
+from joblib import Parallel, delayed
 
 import numpy as np
 
 import spikeextractors as se
 from spikeextractors.baseextractor import _check_json
+from .sorter_tools import SpikeSortingError
 
 
 class BaseSorter:
@@ -38,11 +39,14 @@ class BaseSorter:
     installed = False  # check at class level if isntalled or not
     SortingExtractor_Class = None  # convinience to get the extractor
     requires_locations = False
+    compatible_with_parallel = {'loky': True, 'multiprocessing': True, 'threading': True}
     _default_params = {}
+    _params_description = {}
+    sorter_description = ""
     installation_mesg = ""  # error message when not installed
 
     def __init__(self, recording=None, output_folder=None, verbose=False,
-                 grouping_property=None, parallel=False, delete_output_folder=False):
+                 grouping_property=None, delete_output_folder=False):
 
         assert self.installed, """This sorter {} is not installed.
         Please install it with:  \n{} """.format(self.sorter_name, self.installation_mesg)
@@ -54,13 +58,15 @@ class BaseSorter:
 
         self.verbose = verbose
         self.grouping_property = grouping_property
-        self.parallel = parallel
         self.params = self.default_params()
 
         if output_folder is None:
             output_folder = self.sorter_name + '_output'
         output_folder = Path(output_folder).absolute()
 
+        if output_folder.is_dir():
+            shutil.rmtree(str(output_folder))
+
         if grouping_property is None:
             # only one groups
             self.recording_list = [recording]
@@ -93,8 +99,12 @@ class BaseSorter:
         self.delete_folders = delete_output_folder
 
     @classmethod
-    def default_params(self):
-        return copy.deepcopy(self._default_params)
+    def default_params(cls):
+        return copy.deepcopy(cls._default_params)
+
+    @classmethod
+    def params_description(cls):
+        return copy.deepcopy(cls._params_description)
 
     def set_params(self, **params):
         bad_params = []
@@ -116,7 +126,7 @@ class BaseSorter:
                 params['recording'] = recording.make_serialized_dict()
                 json.dump(_check_json(params), f, indent=4)
 
-    def run(self, raise_error=True):
+    def run(self, raise_error=True, parallel=False, n_jobs=-1, joblib_backend='loky'):
         for i, recording in enumerate(self.recording_list):
             self._setup_recording(recording, self.output_folders[i])
 
@@ -129,46 +139,37 @@ class BaseSorter:
             'sorter_name': str(self.sorter_name),
             'sorter_version': str(self.get_sorter_version()),
             'datetime': now,
+            'runtime_trace': []
         }
 
         t0 = time.perf_counter()
 
-        if raise_error:
-            if not self.parallel:
+        if parallel:
+            assert self.compatible_with_parallel[joblib_backend], f"{self.sorter_name} is not compatible with " \
+                                                                  f"joblib {joblib_backend} backend"
+
+        if parallel and len(self.recording_list) > 1:
+            if not np.all([recording.check_if_dumpable() for recording in self.recording_list]):
+                raise RuntimeError("RecordingExtractor objects are not dumpable and can't be processed in parallel. "
+                                   "Use parallel=False")
+
+        try:
+            if not parallel:
                 for i, recording in enumerate(self.recording_list):
                     self._run(recording, self.output_folders[i])
             else:
-                # run in threads
-                threads = []
-                for i, recording in enumerate(self.recording_list):
-                    thread = threading.Thread(target=self._run, args=(recording, self.output_folders[i]))
-                    threads.append(thread)
-                    thread.start()
-                for thread in threads:
-                    thread.join()
+                Parallel(n_jobs=n_jobs, backend=joblib_backend)(
+                    delayed(self._run)(rec.dump_to_dict(), output_folder)
+                    for (rec, output_folder) in zip(self.recording_list, self.output_folders))
+
             t1 = time.perf_counter()
             run_time = float(t1 - t0)
 
-            log['error'] = False
-
-        else:
-            try:
-                if not self.parallel:
-                    for i, recording in enumerate(self.recording_list):
-                        self._run(recording, self.output_folders[i])
-                else:
-                    # run in threads
-                    threads = []
-                    for i, recording in enumerate(self.recording_list):
-                        thread = threading.Thread(target=self._run, args=(recording, self.output_folders[i]))
-                        threads.append(thread)
-                        thread.start()
-                    for thread in threads:
-                        thread.join()
-                t1 = time.perf_counter()
-                run_time = float(t1 - t0)
-
-            except Exception as err:
+        except Exception as err:
+            if raise_error:
+                raise SpikeSortingError(f"Spike sorting failed: {err}. You can inspect the runtime trace in "
+                                        f"the {self.sorter_name}.log of the output folder.'")
+            else:
                 run_time = None
                 log['error'] = True
                 log['error_trace'] = traceback.format_exc()
@@ -176,7 +177,17 @@ class BaseSorter:
         log['run_time'] = run_time
 
         # dump log inside folders
-        for output_folder in self.output_folders:
+        for i in range(len(self.output_folders)):
+            output_folder = self.output_folders[i]
+            runtime_trace_path = output_folder / f'{self.sorter_name}.log'
+            runtime_trace = []
+            if runtime_trace_path.is_file():
+                with open(runtime_trace_path, 'r') as fp:
+                    line = fp.readline()
+                    while line:
+                        runtime_trace.append(line.strip())
+                        line = fp.readline()
+            log['runtime_trace'] = runtime_trace
             with open(str(output_folder / 'spikeinterface_log.json'), 'w', encoding='utf8') as f:
                 json.dump(_check_json(log), f, indent=4)
 
@@ -190,18 +201,18 @@ class BaseSorter:
 
     @staticmethod
     def get_sorter_version():
-        # need be iplemented in subclass
+        # need be implemented in subclass
         raise NotImplementedError
 
     def _setup_recording(self, recording, output_folder):
-        # need be iplemented in subclass
+        # need be implemented in subclass
         # this setup ONE recording (or SubExtractor)
         # this must copy (or not) the trace in the appropirate format
         # this must take care of geometry file (ORB, CSV, ...)
         raise NotImplementedError
 
     def _run(self, recording, output_folder):
-        # need be iplemented in subclass
+        # need be implemented in subclass
         # this run the sorter on ONE recording (or SubExtractor)
         # this must run or generate the command line to run the sorter for one recording
         raise NotImplementedError
