@@ -9,7 +9,7 @@ import numpy as np
 import spikeextractors as se
 from ..basesorter import BaseSorter
 from ..utils.shellscript import ShellScript
-from ..sorter_tools import get_git_commit
+from ..sorter_tools import get_git_commit, recover_recording
 
 
 def check_if_installed(kilosort_path: Union[str, None]):
@@ -47,6 +47,20 @@ class KilosortSorter(BaseSorter):
         'NT': None
     }
 
+    _params_description = {
+        'detect_threshold': "Threshold for spike detection",
+        'car': "Enable or disable common reference",
+        'useGPU': "Enable or disable GPU usage",
+        'freq_min': "High-pass filter cutoff frequency",
+        'freq_max': "Low-pass filter cutoff frequency",
+        'ntbuff': "Samples of symmetrical buffer for whitening and spike detection",
+        'Nfilt': "Number of clusters to use (if None it is automatically computed)",
+        'NT': "Batch size (if None it is automatically computed)"
+    }
+
+    sorter_description = """Kilosort is a GPU-accelerated and efficient template-matching spike sorter. 
+    For more information see https://papers.nips.cc/paper/6326-fast-and-accurate-spike-sorting-of-high-channel-count-probes-with-kilosort"""
+
     installation_mesg = """\nTo use Kilosort run:\n
         >>> git clone https://github.com/cortex-lab/KiloSort
     and provide the installation path by setting the KILOSORT_PATH
@@ -170,18 +184,20 @@ class KilosortSorter(BaseSorter):
         shutil.copy(str(source_dir.parent / 'utils' / 'constructNPYheader.m'), str(output_folder))
 
     def _run(self, recording, output_folder):
+        recording = recover_recording(recording)
         if 'win' in sys.platform and sys.platform != 'darwin':
             shell_cmd = '''
                         cd {tmpdir}
-                        matlab -nosplash -nodisplay -wait -r kilosort_master
+                        matlab -nosplash -wait -log -r kilosort_master
                     '''.format(tmpdir=output_folder)
         else:
             shell_cmd = '''
                         #!/bin/bash
                         cd "{tmpdir}"
-                        matlab -nosplash -nodisplay -r kilosort_master
+                        matlab -nosplash -nodisplay -log -r kilosort_master
                     '''.format(tmpdir=output_folder)
-        shell_script = ShellScript(shell_cmd, script_path=output_folder / f'run_{self.sorter_name}')
+        shell_script = ShellScript(shell_cmd, script_path=output_folder / f'run_{self.sorter_name}',
+                                   log_path=output_folder / f'{self.sorter_name}.log', verbose=self.verbose)
         shell_script.start()
 
         retcode = shell_script.wait()
