@@ -9,7 +9,7 @@ import json
 import spikeextractors as se
 from ..basesorter import BaseSorter
 from ..utils.shellscript import ShellScript
-from ..sorter_tools import get_git_commit
+from ..sorter_tools import get_git_commit, recover_recording
 
 
 def check_if_installed(kilosort2_path: Union[str, None]):
@@ -21,7 +21,7 @@ def check_if_installed(kilosort2_path: Union[str, None]):
         kilosort2_path = kilosort2_path[1:-1]
     kilosort2_path = str(Path(kilosort2_path).absolute())
 
-    if (Path(kilosort2_path) / 'master_kilosort.m').is_file():
+    if (Path(kilosort2_path) / 'master_kilosort.m').is_file() or (Path(kilosort2_path) / 'main_kilosort.m').is_file():
         return True
     else:
         return False
@@ -52,6 +52,29 @@ class Kilosort2Sorter(BaseSorter):
         'keep_good_only': False
     }
 
+    _params_description = {
+        'detect_threshold': "Threshold for spike detection",
+        'car': "Enable or disable common reference",
+        'useGPU': "Enable or disable GPU usage",
+        'freq_min': "High-pass filter cutoff frequency",
+        'freq_max': "Low-pass filter cutoff frequency",
+        'ntbuff': "Samples of symmetrical buffer for whitening and spike detection",
+        'Nfilt': "Number of clusters to use (if None it is automatically computed)",
+        'NT': "Batch size (if None it is automatically computed)",
+        'projection_threshold': "Threshold on projections",
+        'preclust_threshold': "Threshold crossings for pre-clustering (in PCA projection space)",
+        'minFR': "Minimum spike rate (Hz), if a cluster falls below this for too long it gets removed",
+        'minfr_goodchannels': "Minimum firing rate on a 'good' channel",
+        'sigmaMask': "Spatial constant in um for computing residual variance of spike",
+        'nPCs': "Number of PCA dimensions",
+        'nfilt_factor': "Max number of clusters per good channel (even temporary ones) 4",
+        'keep_good_only': "If True only 'good' units are returned"
+    }
+
+    sorter_description = """Kilosort2 is a GPU-accelerated and efficient template-matching spike sorter. On top of its 
+    predecessor Kilosort, it implements a drift-correction strategy.
+    For more information see https://github.com/MouseLand/Kilosort2"""
+
     installation_mesg = """\nTo use Kilosort2 run:\n
         >>> git clone https://github.com/MouseLand/Kilosort2
     and provide the installation path by setting the KILOSORT2_PATH
@@ -98,7 +121,7 @@ class Kilosort2Sorter(BaseSorter):
             raise RuntimeError("3D 'location' are not supported. Set 2D locations instead")
 
         # save binary file
-        input_file_path = output_folder / 'recording'
+        input_file_path = output_folder / 'recording.dat'
         recording.write_to_binary_dat_format(input_file_path, dtype='int16', chunk_mb=500)
 
         if p['car']:
@@ -166,20 +189,21 @@ class Kilosort2Sorter(BaseSorter):
         shutil.copy(str(source_dir.parent / 'utils' / 'constructNPYheader.m'), str(output_folder))
 
     def _run(self, recording, output_folder):
+        recording = recover_recording(recording)
         if 'win' in sys.platform and sys.platform != 'darwin':
             shell_cmd = '''
                         cd {tmpdir}
-                        matlab -nosplash -nodisplay -wait -r kilosort2_master
+                        matlab -nosplash -wait -log -r kilosort2_master
                     '''.format(tmpdir=output_folder)
         else:
             shell_cmd = '''
                         #!/bin/bash
                         cd "{tmpdir}"
-                        matlab -nosplash -nodisplay -r kilosort2_master
+                        matlab -nosplash -nodisplay -log -r kilosort2_master
                     '''.format(tmpdir=output_folder)
-        shell_script = ShellScript(shell_cmd, script_path=output_folder / f'run_{self.sorter_name}')
+        shell_script = ShellScript(shell_cmd, script_path=output_folder / f'run_{self.sorter_name}',
+                                   log_path=output_folder / f'{self.sorter_name}.log', verbose=self.verbose)
         shell_script.start()
-
         retcode = shell_script.wait()
 
         if retcode != 0:
