@@ -2,11 +2,13 @@ import copy
 from pathlib import Path
 import os
 import numpy as np
+from numpy.lib.format import open_memmap
 import sys
 
 import spikeextractors as se
 from ..basesorter import BaseSorter
 from ..utils.shellscript import ShellScript
+from ..sorter_tools import recover_recording
 
 try:
     import circus
@@ -36,7 +38,24 @@ class SpykingcircusSorter(BaseSorter):
         'clustering_max_elts': 10000,  # I believe it relates to subsampling and affects compute time
         }
 
-    installation_mesg = """
+    _params_description = {
+        'detect_sign': "Use -1 (negative), 1 (positive) or 0 (both) depending "
+                       "on the sign of the spikes in the recording",
+        'adjacency_radius': "Radius in um to build channel neighborhood",
+        'detect_threshold': "Threshold for spike detection",
+        'template_width_ms': "Template width in ms. Recommended values: 3 for in vivo - 5 for in vitro",
+        'filter': "Enable or disable filter",
+        'merge_spikes': "Enable or disable automatic mergind",
+        'auto_merge': "Automatic merging threshold",
+        'num_workers': "Number of workers (if None, half of the cpu number is used)",
+        'whitening_max_elts': "Max number of events per electrode for whitening",
+        'clustering_max_elts': "Max number of events per electrode for clustering",
+    }
+
+    sorter_description = """Spyking Circus uses a smart clustering and a greedy template matching approach for 
+    spike sorting. For more information see https://doi.org/10.7554/eLife.34518"""
+
+    installation_mesg = """\nTo use Spyking-Circus run:\n
         >>> pip install spyking-circus
 
         Need MPICH working, for ubuntu do:
@@ -67,8 +86,6 @@ class SpykingcircusSorter(BaseSorter):
         file_name = 'recording'
         # We should make this copy more efficient with chunks
 
-        from numpy.lib.format import open_memmap
-
         n_chan = recording.get_num_channels()
         n_frames = recording.get_num_frames()
         chunk_size = 2 ** 24 // n_chan
@@ -107,6 +124,7 @@ class SpykingcircusSorter(BaseSorter):
             p['num_workers'] = np.maximum(1, int(os.cpu_count()/2))
 
     def _run(self,  recording, output_folder):
+        recording = recover_recording(recording)
         if recording.is_filtered and self.params['filter']:
             print("Warning! The recording is already filtered, but Spyking-Circus filter is enabled. You can disable "
                   "filters by setting 'filter' parameter to False")
@@ -122,7 +140,8 @@ class SpykingcircusSorter(BaseSorter):
                         spyking-circus {recording} -c {num_workers}
                     '''.format(recording=output_folder / 'recording.npy', num_workers=num_workers)
 
-        shell_script = ShellScript(shell_cmd, script_path=output_folder / f'run_{self.sorter_name}')
+        shell_script = ShellScript(shell_cmd, script_path=output_folder / f'run_{self.sorter_name}',
+                                   log_path=output_folder / f'{self.sorter_name}.log', verbose=self.verbose)
         shell_script.start()
 
         retcode = shell_script.wait()
